@@ -1,4 +1,4 @@
-from typing import Union
+from typing import List, Union
 
 import graphql
 
@@ -6,3 +6,5 @@ import graphql
 ScalarValueNode = Union[graphql.IntValueNode, graphql.FloatValueNode, graphql.StringValueNode, graphql.BooleanValueNode]
 InputTypeNode = Union[ScalarValueNode, graphql.EnumValueNode, graphql.ListValueNode, graphql.ObjectValueNode]
 Field = Union[graphql.GraphQLField, graphql.GraphQLInputField]
+InterfaceOrObject = Union[graphql.GraphQLObjectType, graphql.GraphQLInterfaceType]
+SelectionNodes = List[graphql.SelectionNode]
